@@ -1,5 +1,9 @@
 
 # version of comotion-sdk. Used for doc building and code building.
-__version__ = '0.0.4'
 __projectname__ = 'comotion-sdk'
 __author__ = "Tim Vieyra"
+
+import comotion.auth
+from comotion.auth import Auth
+
+import comodash_api_client_lowlevel
